==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXPingManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingManager;no warnings;(my $__pingRequestTime=(0x0323+ 2524-0x0cff));
(my $__pingTime=(0x0022+ 8359-0x20c9));(my $__interval=(0x0d03+ 5030-0x20a9));(my $__timeout
=(0x0519+ 2322-0x0e2b));(my $__errorTimeout=(0x0881+ 2177-0x1102));sub 
initialize{__setTimeBetweenPingsFromNode ();__setTimeoutForPingAfterRequest ();
__setPingRequestTime ();}sub __setTimeBetweenPingsFromNode{($__interval=
(0x08db+ 2982-0x1436));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x6e\x6f\x64\x65\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingAfterRequest{($__timeout=
NXNodeConfiguration::getNodeConnectionTimeout ());Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x61\x66\x74\x65\x72\x20\x72\x65\x71\x75\x65\x73\x74\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndRequestPingIfNecessary{if ((
__isPingEnabled ()==(0x11ed+ 3553-0x1fce))){return;}if ((__isTimeout ()==
(0x07d6+ 2006-0x0fab))){if ((__isErrorTimeout ()==(0x03d3+ 1371-0x092d))){(my $msg
=((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));Logger::error ($msg);Logger::statusPushError ($msg);die ($msg);}
__setErrorTimeout ();Logger::warning (((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPingRequest ();
return;}if ((__isPingRequestTime ()==(0x037d+  39-0x03a3))){__sendPingRequest ()
;return;}}sub handlePing{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__resetPingRequestTime ();__clearErrorTimeout ();Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PONG)."\x20")
.$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PONG})."\x0a"));__setPingTime ();}
sub __isPingRequestTime{if (($__pingTime==(0x09d3+ 5955-0x2116))){return (
(0x1d0a+ 2428-0x2686));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$time>=($__pingTime+$__interval))){return ((0x0025+ 7774-0x1e82));}return (
(0x164a+ 2275-0x1f2d));}sub __resetPingRequestTime{($__pingRequestTime=
(0x0488+ 4173-0x14d5));}sub __setPingRequestTime{($__pingRequestTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __sendPingRequest{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x72\x65\x71\x75\x65\x73\x74\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_REQUEST_FOR_PING).
"\x20").$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_REQUEST_FOR_PING})."\x0a"));
__setPingRequestTime ();__resetPingTime ();}sub disable{($__timeout=
(0x07ff+ 4168-0x1847));Logger::debug (
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x44\x69\x73\x61\x62\x6c\x65\x20\x70\x69\x6e\x67\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);}sub __isPingEnabled{if (($__timeout==(0x07fd+ 6294-0x2093))){return (
(0x2385+ 501-0x257a));}return ((0x129a+ 1482-0x1863));}sub __isTimeout{if ((
$__pingRequestTime==(0x039c+ 7545-0x2115))){return ((0x0cac+ 1509-0x1291));}(my $time
=Common::NXTime::getSecondsSinceEpoch ());if (($__pingRequestTime>$time)){(
$__pingRequestTime=Common::NXTime::getSecondsSinceEpoch ());}if (($time>=(
$__pingRequestTime+$__timeout))){return ((0x0b20+ 6193-0x2350));}return (
(0x0bc5+ 5853-0x22a2));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x02ac+ 4072-0x1294));}sub __setErrorTimeout{($__errorTimeout=
(0x010a+ 9256-0x2531));}sub __isErrorTimeout{return ($__errorTimeout);}sub 
__clearErrorTimeout{($__errorTimeout=(0x13c4+ 325-0x1509));}return (
(0x0290+ 1762-0x0971));

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXPingManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingManager;no warnings;(my $__pingRequestTime=(0x0284+ 182-0x033a));(my $__pingTime
=(0x02a0+ 9162-0x266a));(my $__interval=(0x0119+ 4034-0x10db));(my $__timeout=
(0x1694+ 1489-0x1c65));(my $__errorTimeout=(0x0647+ 4709-0x18ac));sub initialize
{__setTimeBetweenPingsFromNode ();__setTimeoutForPingAfterRequest ();
__setPingRequestTime ();}sub __setTimeBetweenPingsFromNode{($__interval=
(0x13b8+ 874-0x16d7));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x6e\x6f\x64\x65\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingAfterRequest{($__timeout=
NXNodeConfiguration::getNodeConnectionTimeout ());Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x61\x66\x74\x65\x72\x20\x72\x65\x71\x75\x65\x73\x74\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndRequestPingIfNecessary{if ((
__isPingEnabled ()==(0x03b8+ 8237-0x23e5))){return;}if ((__isTimeout ()==
(0x1017+ 5144-0x242e))){if ((__isErrorTimeout ()==(0x090a+ 2114-0x114b))){(my $msg
=((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));Logger::error ($msg);Logger::statusPushError ($msg);die ($msg);}
__setErrorTimeout ();Logger::warning (((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPingRequest ();
return;}if ((__isPingRequestTime ()==(0x1d79+ 459-0x1f43))){__sendPingRequest ()
;return;}}sub handlePing{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__resetPingRequestTime ();__clearErrorTimeout ();Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PONG)."\x20")
.$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PONG})."\x0a"));__setPingTime ();}
sub __isPingRequestTime{if (($__pingTime==(0x08ea+ 5608-0x1ed2))){return (
(0x1677+ 382-0x17f5));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$time>=($__pingTime+$__interval))){return ((0x0a84+ 2778-0x155d));}return (
(0x00ff+ 604-0x035b));}sub __resetPingRequestTime{($__pingRequestTime=
(0x0371+ 1596-0x09ad));}sub __setPingRequestTime{($__pingRequestTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __sendPingRequest{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x72\x65\x71\x75\x65\x73\x74\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_REQUEST_FOR_PING).
"\x20").$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_REQUEST_FOR_PING})."\x0a"));
__setPingRequestTime ();__resetPingTime ();}sub disable{($__timeout=
(0x06af+ 4663-0x18e6));Logger::debug (
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x44\x69\x73\x61\x62\x6c\x65\x20\x70\x69\x6e\x67\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);}sub __isPingEnabled{if (($__timeout==(0x1359+ 3035-0x1f34))){return (
(0x127d+ 2223-0x1b2c));}return ((0x0a6b+ 5574-0x2030));}sub __isTimeout{if ((
$__pingRequestTime==(0x0b9b+ 5359-0x208a))){return ((0x0d30+ 465-0x0f01));}(my $time
=Common::NXTime::getSecondsSinceEpoch ());if (($__pingRequestTime>$time)){(
$__pingRequestTime=Common::NXTime::getSecondsSinceEpoch ());}if (($time>=(
$__pingRequestTime+$__timeout))){return ((0x0379+ 8816-0x25e8));}return (
(0x0e23+ 6018-0x25a5));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x012a+ 1095-0x0571));}sub __setErrorTimeout{($__errorTimeout=
(0x1693+ 2898-0x21e4));}sub __isErrorTimeout{return ($__errorTimeout);}sub 
__clearErrorTimeout{($__errorTimeout=(0x0247+ 5110-0x163d));}return (
(0x0c2f+ 524-0x0e3a));
